import { Button, TableCell, TableRow } from '@mui/material'
import ConfirmDialog from 'components/confirmDialog'
import { Identity } from 'interfaces'
import { useState } from 'react'
import { submitJsonOpts } from 'utils'
import CheckIcon from '@mui/icons-material/Check'
import { useTranslation } from 'react-i18next'
import { styled } from '@mui/system'

interface IdentityLineProps {
  text: string
  identity: Identity | null
  reloadGuest: () => void
  reloadGuests: () => void
}

const StyledTableCell = styled(TableCell)({
  border: 'none',
})

const IdentityLine = ({
  text,
  identity,
  reloadGuest,
  reloadGuests,
}: IdentityLineProps) => {
  // Make a line with a confirmation button if the identity has not been verified
  const [confirmOpen, setConfirmOpen] = useState(false)
  const [t] = useTranslation('common')
  const verifyIdentity = (id: string) => async () => {
    await fetch(`/api/ui/v1/identity/${id}`, submitJsonOpts('PATCH', {}))
    reloadGuest()
    reloadGuests()
  }

  if (identity == null) {
    return <></>
  }
  return (
    <TableRow>
      <StyledTableCell align="left">{text}</StyledTableCell>
      <StyledTableCell align="left">
        {identity ? identity.value : ''}
      </StyledTableCell>
      <StyledTableCell>
        {!identity.verified_at ? (
          <div>
            <Button
              aria-label={t('button.verify')}
              onClick={() => setConfirmOpen(true)}
              disabled={!identity}
            >
              {t('button.verify')}
            </Button>
            <ConfirmDialog
              title={t('confirmationDialog.confirmIdentityTitle')}
              open={confirmOpen}
              setOpen={setConfirmOpen}
              onConfirm={verifyIdentity(identity.id)}
            >
              {t('confirmationDialog.confirmIdentityText')}
            </ConfirmDialog>
          </div>
        ) : (
          <CheckIcon sx={{ fill: (theme) => theme.palette.success.main }} />
        )}
      </StyledTableCell>
    </TableRow>
  )
}

export default IdentityLine
